@@ -5,8 +5,7 @@ import typer_cloup as typer
 
 def iterate_user_ids():
     # Let's imagine this is a web API, not a range()
-    for i in range(100):
-        yield i
+    yield from range(100)
 
 
 def main():
