@@ -5,9 +5,9 @@ import lands
 import users
 
 app = typer.Typer()
-app.add_typer(users.app, name="users")
-app.add_typer(items.app, name="items")
-app.add_typer(lands.app, name="lands")
+app.add_sub(users.app, name="users")
+app.add_sub(items.app, name="items")
+app.add_sub(lands.app, name="lands")
 
 if __name__ == "__main__":
     app()
