@@ -1,11 +1,9 @@
 import os
 import subprocess
 from pathlib import Path
-from unittest import mock
 
 import click
 import pytest
-import shellingham
 
 import typer_cloup as typer
 from typer_cloup.main import solve_typer_info_defaults, solve_typer_info_help
@@ -32,15 +30,10 @@ def test_install_invalid_shell():
 
     @app.command()
     def main():
-        typer.echo("Hello World")
+        pass  # pragma: no cover
 
-    with mock.patch.object(
-        shellingham, "detect_shell", return_value=("xshell", "/usr/bin/xshell")
-    ):
-        result = runner.invoke(app, ["--install-completion"])
-        assert "Shell xshell is not supported." in result.stdout
-    result = runner.invoke(app)
-    assert "Hello World" in result.stdout
+    result = runner.invoke(app, env={"_MAIN_COMPLETE": "xshell_source"})
+    assert "Shell 'xshell' is not supported." in result.stdout
 
 
 def test_callback_too_many_parameters():
@@ -86,7 +79,7 @@ def test_callback_3_untyped_parameters():
 
     @app.command()
     def main(name: str = typer.Option(..., callback=name_callback)):
-        typer.echo("Hello World")
+        pass
 
     result = runner.invoke(app, ["--name", "Camila"])
     assert "info name is: main" in result.stdout
@@ -103,16 +96,20 @@ def test_completion_untyped_parameters():
         encoding="utf-8",
         env={
             **os.environ,
-            "_COMPLETION_NO_TYPES.PY_COMPLETE": "complete_zsh",
-            "_TYPER_COMPLETE_ARGS": "completion_no_types.py --name Sebastian --name Ca",
+            "_COMPLETION_NO_TYPES.PY_COMPLETE": "zsh_complete",
+            "COMP_WORDS": "completion_no_types.py --name Sebastian --name Ca",
+            "COMP_CWORD": "4",
             "_TYPER_COMPLETE_TESTING": "True",
         },
     )
     assert "info name is: completion_no_types.py" in result.stderr
     assert "param is: name" in result.stderr
     assert "incomplete is: Ca" in result.stderr
-    assert '"Camila":"The reader of books."' in result.stdout
-    assert '"Carlos":"The writer of scripts."' in result.stdout
+    assert (
+        "plain\nCamila\nThe reader of books.\n"
+        "plain\nCarlos\nThe writer of scripts.\n"
+        "plain\nSebastian\nThe type hints guy.\n" in result.stdout
+    )
 
     result = subprocess.run(
         ["coverage", "run", str(file_path)],
@@ -132,16 +129,19 @@ def test_completion_untyped_parameters_different_order_correct_names():
         encoding="utf-8",
         env={
             **os.environ,
-            "_COMPLETION_NO_TYPES_ORDER.PY_COMPLETE": "complete_zsh",
-            "_TYPER_COMPLETE_ARGS": "completion_no_types_order.py --name Sebastian --name Ca",
+            "_COMPLETION_NO_TYPES_ORDER.PY_COMPLETE": "zsh_complete",
+            "COMP_WORDS": "completion_no_types.py --name Sebastian --name Ca",
+            "COMP_CWORD": "4",
             "_TYPER_COMPLETE_TESTING": "True",
         },
     )
     assert "info name is: completion_no_types_order.py" in result.stderr
     assert "param is: name" in result.stderr
     assert "incomplete is: Ca" in result.stderr
-    assert '"Camila":"The reader of books."' in result.stdout
-    assert '"Carlos":"The writer of scripts."' in result.stdout
+    assert (
+        "plain\nCamila\nThe reader of books.\n"
+        "plain\nCarlos\nThe writer of scripts.\n" in result.stdout
+    )
 
     result = subprocess.run(
         ["coverage", "run", str(file_path)],
@@ -269,16 +269,17 @@ def test_help_defaults():
     assert "(dynamic)" in result.output
 
 
-def test_help_auto_envvar_prefix():
-    app = typer.Typer(context_settings=dict(auto_envvar_prefix="TEST"))
+def test_help_option_envvar():
+    # Mainly for coverage/completeness
+    app = typer.Typer()
 
     @app.command()
-    def main(name: str = typer.Option(...)):
-        pass  # pragma: no cover
+    def main(name: str = typer.Option("World", envvar="AWESOME_NAME")):
+        typer.echo(f"Hello Mr. {name}")
 
-    result = runner.invoke(app, ["main", "--help"])
+    result = runner.invoke(app, env={"AWESOME_NAME": "Wednesday"})
     assert result.exit_code == 0
-    assert "env var: TEST_NAME" in result.output
+    assert "Hello Mr. Wednesday" in result.output
 
 
 def test_help_slash_option():
@@ -293,20 +294,20 @@ def test_help_slash_option():
     assert "/name TEXT" in result.output
 
 
-def test_help_hidden_option():
+def test_help_hidden_parameter():
     app = typer.Typer()
 
     @app.command()
     def main(
-        name: str = typer.Option(..., hidden=True),
-        lastname: str = typer.Option(...),
+        name: str = typer.Argument(..., hidden=True),
+        lastname: str = typer.Option(..., hidden=True),
     ):
         pass  # pragma: no cover
 
     result = runner.invoke(app, ["main", "--help"])
     assert result.exit_code == 0
-    assert "--name" not in result.output
-    assert "lastname" in result.output
+    assert "  NAME" not in result.output
+    assert "--lastname" not in result.output
 
 
 def test_help_hidden_group():
