@@ -47,7 +47,7 @@ def test_completion():
         encoding="utf-8",
         env={
             **os.environ,
-            "_TUTORIAL003.PY_COMPLETE": "complete_bash",
+            "_TUTORIAL003.PY_COMPLETE": "bash_complete",
             "COMP_WORDS": "tutorial003.py --name Rick --v",
             "COMP_CWORD": "3",
             "_TYPER_COMPLETE_TESTING": "True",
