@@ -15,14 +15,17 @@ def test_completion():
         encoding="utf-8",
         env={
             **os.environ,
-            "_TUTORIAL007.PY_COMPLETE": "complete_zsh",
-            "_TYPER_COMPLETE_ARGS": "tutorial007.py --name Sebastian --name ",
+            "_TUTORIAL007.PY_COMPLETE": "zsh_complete",
+            "COMP_WORDS": "tutorial007.py --name Sebastian --name ",
+            "COMP_CWORD": "4",
             "_TYPER_COMPLETE_TESTING": "True",
         },
     )
-    assert '"Camila":"The reader of books."' in result.stdout
-    assert '"Carlos":"The writer of scripts."' in result.stdout
-    assert '"Sebastian":"The type hints guy."' not in result.stdout
+    assert (
+        "plain\nCamila\nThe reader of books.\n"
+        "plain\nCarlos\nThe writer of scripts.\n" in result.stdout
+    )
+    assert "Sebastian" not in result.stdout
 
 
 def test_1():
