@@ -27,7 +27,6 @@ try:
 except ImportError:  # pragma: no cover
     docstring_parser = None  # type: ignore
 
-from .completion import get_completion_inspect_parameters
 from .core import TyperArgument, TyperCommand, TyperGroup, TyperOption
 from .models import (
     AnyType,
@@ -47,20 +46,16 @@ from .models import (
     Required,
     TyperInfo,
 )
+from .param_types import SHELL_QUOTED_LIST
 from .utils import get_params_from_function
 
 if TYPE_CHECKING:  # pragma: no cover
     from cloup.constraints import BoundConstraintSpec
 
 
-def get_install_completion_arguments() -> Tuple[click.Parameter, click.Parameter]:
-    install_param, show_param = get_completion_inspect_parameters()
-    click_install_param, _ = get_click_param(install_param)
-    click_show_param, _ = get_click_param(show_param)
-    return click_install_param, click_show_param
-
-
 class Typer:
+    """A CLI application based on type hints."""
+
     def __init__(
         self,
         *,
@@ -89,10 +84,7 @@ class Typer:
         deprecated: bool = Default(False),
         align_option_groups: Optional[bool] = Default(None),
         show_constraints: Optional[bool] = Default(None),
-        # Completion
-        add_completion: bool = True,
     ):
-        self._add_completion = add_completion
         self.info = TyperInfo(
             self,
             name=name,
@@ -149,6 +141,8 @@ class Typer:
         align_option_groups: Optional[bool] = Default(None),
         show_constraints: Optional[bool] = Default(None),
     ) -> Callable[[CommandFunctionType], CommandFunctionType]:
+        """Callback function decorator."""
+
         def decorator(f: CommandFunctionType) -> CommandFunctionType:
             info = TyperInfo(
                 self,
@@ -201,6 +195,7 @@ class Typer:
         align_option_groups: Optional[bool] = None,
         show_constraints: Optional[bool] = None,
     ) -> Callable[[CommandFunctionType], CommandFunctionType]:
+        """Command function decorator"""
         if cls is None:
             cls = TyperCommand
 
@@ -259,6 +254,7 @@ class Typer:
         align_option_groups: Optional[bool] = Default(None),
         show_constraints: Optional[bool] = Default(None),
     ) -> None:
+        """Add the given sub-application to this application."""
         self.registered_groups.append(
             TyperInfo(
                 typer_instance,
@@ -294,11 +290,10 @@ class Typer:
         **kwargs: Any,
     ) -> Any:
         """
-        Invokes a callable that is a registered command or subcommand of the given `Typer` instance.
+        Invoke a callable that is a registered command or subcommand of the given `Typer` instance.
 
         Other arguments are passed on to `click.Context.invoke`.
         """
-
         info = getattr(callback, "_command_info", None)
         if not info:
             raise TypeError("callback is not a command")
@@ -315,11 +310,10 @@ class Typer:
         **kwargs: Any,
     ) -> Any:
         """
-        Forwards a callable that is a registered command or subcommand of the given `Typer` instance.
+        Forward a callable that is a registered command or subcommand of the given `Typer` instance.
 
         Other arguments are passed on to `click.Context.forward`.
         """
-
         info = getattr(callback, "_command_info", None)
         if not info:
             raise TypeError("callback is not a command")
@@ -371,8 +365,6 @@ def get_group(typer_instance: Typer) -> click.Group:
 
 
 def get_command(typer_instance: Typer) -> click.Command:
-    if typer_instance._add_completion:
-        click_install_param, click_show_param = get_install_completion_arguments()
     if (
         typer_instance.registered_callback
         or typer_instance.info.callback
@@ -380,11 +372,7 @@ def get_command(typer_instance: Typer) -> click.Command:
         or len(typer_instance.registered_commands) > 1
     ):
         # Create a Group
-        click_command = cast(click.Command, get_group(typer_instance))
-        if typer_instance._add_completion:
-            click_command.params.append(click_install_param)
-            click_command.params.append(click_show_param)
-        return click_command
+        return cast(click.Command, get_group(typer_instance))
     elif len(typer_instance.registered_commands) == 1:
         # Create a single Command
         single_command = typer_instance.registered_commands[0]
@@ -394,11 +382,7 @@ def get_command(typer_instance: Typer) -> click.Command:
         ):
             single_command.context_settings = typer_instance.info.context_settings
 
-        click_command = get_command_from_info(single_command)
-        if typer_instance._add_completion:
-            click_command.params.append(click_install_param)
-            click_command.params.append(click_show_param)
-        return click_command
+        return get_command_from_info(single_command)
     assert False, "Could not get a command for this Typer instance"  # pragma no cover
 
 
@@ -757,6 +741,8 @@ def get_constraints(
 def get_click_type(
     *, annotation: Any, parameter_info: ParameterInfo
 ) -> click.ParamType:
+    if annotation == Any:
+        return click.UNPROCESSED
     if annotation == str:
         return click.STRING
     elif annotation == int:
@@ -851,7 +837,7 @@ def get_click_param(
     param: ParamMeta,
 ) -> Tuple[Union[click.Argument, click.Option], Any]:
     # First, find out what will be:
-    # * ParamInfo (ArgumentInfo or OptionInfo)
+    # * ParameterInfo (ArgumentInfo or OptionInfo)
     # * default_value
     # * required
     default_value = None
@@ -879,7 +865,10 @@ def get_click_param(
     parameter_type: Any = None
     is_flag = None
     origin = getattr(main_type, "__origin__", None)
-    if origin is not None:
+    if parameter_info.type is not None:
+        main_type = parameter_info.type
+        parameter_type = parameter_info.type
+    elif origin is not None:
         # Handle Optional[SomeType]
         if origin is Union:
             types = []
@@ -896,7 +885,10 @@ def get_click_param(
             assert not getattr(
                 main_type, "__origin__", None
             ), "List types with complex sub-types are not currently supported"
-            is_list = True
+            if parameter_info.shell_quoted_list:
+                parameter_type = SHELL_QUOTED_LIST
+            else:
+                is_list = True
         elif lenient_issubclass(origin, Tuple):  # type: ignore
             types = []
             for type_ in main_type.__args__:
@@ -913,7 +905,7 @@ def get_click_param(
             annotation=main_type, parameter_info=parameter_info
         )
     convertor = determine_type_convertor(main_type)
-    if is_list:
+    if is_list or parameter_type is SHELL_QUOTED_LIST:
         convertor = generate_list_convertor(convertor)
     if is_tuple:
         convertor = generate_tuple_convertor(main_type.__args__)
@@ -988,6 +980,7 @@ def get_click_param(
                 show_default=parameter_info.show_default,
                 show_choices=parameter_info.show_choices,
                 show_envvar=parameter_info.show_envvar,
+                allow_from_autoenv=parameter_info.allow_from_autoenv,
                 help=parameter_info.help,
                 hidden=parameter_info.hidden,
                 # Parameter
@@ -1028,7 +1021,7 @@ def get_param_callback(
     # Extract value param name first
     if untyped_names:
         value_name = untyped_names.pop()
-    # If context and Click param were not typed (old/Click callback style) extract them
+    # If context and Click param were not typed (old/Click callback style), extract them
     if untyped_names:
         if ctx_name is None:
             ctx_name = untyped_names.pop(0)
@@ -1113,6 +1106,6 @@ def get_param_completion(
 
 
 def run(function: Callable[..., Any]) -> None:
-    app = Typer(add_completion=False)
+    app = Typer()
     app.command()(function)
     app()
